﻿local Medley = LibStub("AceAddon-3.0"):NewAddon("Medley", "AceConsole-3.0", "AceEvent-3.0")
local quixote = LibStub("LibQuixote-2.0")
local L = LibStub("AceLocale-3.0"):GetLocale("Medley")

function Medley:OnInitialize()
	Medley.db = LibStub("AceDB-3.0"):New("MedleyDB", Medley.defaults, "Default")
	Medley.options.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(Medley.db)
    LibStub("AceConfig-3.0"):RegisterOptionsTable("Medley", Medley.options)
    self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Medley", "Medley")
    self:RegisterChatCommand("medley", function() InterfaceOptionsFrame_OpenToFrame(self.optionsFrame) end)
end

function Medley:OnEnable()
   	quixote.RegisterCallback(self, "Objective_Update")
    quixote.RegisterCallback(self, "Quest_Complete")
    quixote.RegisterCallback(self, "Quest_Failed")
    Medley:RegisterEvent("PLAYER_LEVEL_UP")
    Medley:RegisterEvent("DUEL_FINISHED")
    Medley:RegisterEvent("AUTOFOLLOW_BEGIN")
    Medley:RegisterEvent("UPDATE_PENDING_MAIL")
    Medley:RegisterEvent("MAIL_INBOX_UPDATE")
    Medley:RegisterEvent("MAIL_CLOSED")
    Medley:RegisterEvent("CHAT_MSG_WHISPER")
end

Medley.options = {
    type = "group",
    childGroups = "tab",
    name = L["Medley"],
    desc = L["Customizable sounds for your adventures!"],
    args = {
        url = {
        type = "header",
        name = L["Beta v.1b - Thank you for helping me test this mod! :)"],
        },
        moreoptions = {
        type = "group",
        name = L["Options"],
        desc = L["Customize the addon!"],
        order = 1,
        args = {
    
            questobjectives = {
                type = "group",
                order = 1,
                name = L["Objective Complete"],
                desc = L["Plays on completion of quest objective."],
                args = {
                    enabled = {
                    name = L["Enabled"],
                    desc = L["Enables or disables this sound."],
                    type = "toggle",
                    get = function(info) return Medley.db.profile.QuestObjectivesEnabled end,
                    set = function(info,val) Medley.db.profile.QuestObjectivesEnabled = val end
                    },
                    sound = {
                    name = L["Sound"],
                    desc = L["Must be a path to an in-game sound or in the Interface directory."],
                    type = "input",
                    get = function(info) return Medley.db.profile.QuestObjectivesSound end,
                    set = function(info,val) Medley.db.profile.QuestObjectivesSound = val end
                    },
                }
            },
            questcomplete = {
                type = "group",
                order = 2,
                name = L["Quest Complete"],
                desc = L["Plays on full completion of a quest."],
                args = {
                    enabled = {
                    name = L["Enabled"],
                    desc = L["Enables or disables this sound."],
                    type = "toggle",
                    get = function(info) return Medley.db.profile.QuestCompleteEnabled end,
                    set = function(info,val) Medley.db.profile.QuestCompleteEnabled = val end
                    },
                    sound = {
                    name = L["Sound"],
                    desc = L["Must be a path to an in-game sound or in the Interface directory."],
                    type = "input",
                    get = function(info) return Medley.db.profile.QuestCompleteSound end,
                    set = function(info,val) Medley.db.profile.QuestCompleteSound = val end
                    },
                }
            },
            questfailed = {
                type = "group",
                order = 3,
                name = L["Quest Failed"],
                desc = L["Plays on failure of a quest."],
                args = {
                    enabled = {
                    name = L["Enabled"],
                    desc = L["Enables or disables this sound."],
                    type = "toggle",
                    get = function(info) return Medley.db.profile.QuestFailedEnabled end,
                    set = function(info,val) Medley.db.profile.QuestFailedsEnabled = val end
                    },
                    sound = {
                    name = L["Sound"],
                    desc = L["Must be a path to an in-game sound or in the Interface directory."],
                    type = "input",
                    get = function(info) return Medley.db.profile.QuestFailedSound end,
                    set = function(info,val) Medley.db.profile.QuestFailedSound = val end
                    },
                }
            },
            levelup = {
                type = "group",
                order = 4,
                name = L["Level Up"],
                desc = L["Plays when you level up."],
                args = {
                    enabled = {
                    name = L["Enabled"],
                    desc = L["Enables or disables this sound."],
                    type = "toggle",
                    get = function(info) return Medley.db.profile.LevelUpEnabled end,
                    set = function(info,val) Medley.db.profile.LevelUpEnabled = val end
                    },
                    sound = {
                    name = L["Sound"],
                    desc = L["Must be a path to an in-game sound or in the Interface directory."],
                    type = "input",
                    get = function(info) return Medley.db.profile.LevelUpSound end,
                    set = function(info,val) Medley.db.profile.LevelUpSound = val end
                    },
                }
            },
            duelfinished = {
                type = "group",
                order = 5,
                name = L["Duel Finished"],
                desc = L["Plays when a duel is finished, won or lost."],
                args = {
                    enabled = {
                    name = L["Enabled"],
                    desc = L["Enables or disables this sound."],
                    type = "toggle",
                    get = function(info) return Medley.db.profile.DuelFinishedEnabled end,
                    set = function(info,val) Medley.db.profile.DuelFinishedEnabled = val end
                    },
                    sound = {
                    name = L["Sound"],
                    desc = L["Must be a path to an in-game sound or in the Interface directory."],
                    type = "input",
                    get = function(info) return Medley.db.profile.DuelFinishedSound end,
                    set = function(info,val) Medley.db.profile.DuelFinishedSound = val end
                    },
                }
            },
            mailnotify = {
                type = "group",
                order = 6,
                name = L["Mail Notification"],
                desc = L["Plays when new mail arrives."],
                args = {
                    enabled = {
                    name = L["Enabled"],
                    desc = L["Enables or disables this sound."],
                    type = "toggle",
                    get = function(info) return Medley.db.profile.MailNotifyEnabled end,
                    set = function(info,val) Medley.db.profile.MailNotifyEnabled = val end
                    },
                    sound = {
                    name = L["Sound"],
                    desc = L["Must be a path to an in-game sound or in the Interface directory."],
                    type = "input",
                    get = function(info) return Medley.db.profile.MailNotifySound end,
                    set = function(info,val) Medley.db.profile.MailNotifySound = val end
                    },
                }
            },
            whispernotify = {
                type = "group",
                order = 7,
                name = L["Whisper Notification"],
                desc = L["Plays whenever a whisper/tell is received."],
                args = {
                    enabled = {
                    name = L["Enabled"],
                    desc = L["Enables or disables this sound."],
                    type = "toggle",
                    get = function(info) return Medley.db.profile.WhisperNotifyEnabled end,
                    set = function(info,val) Medley.db.profile.WhisperNotifyEnabled = val end
                    },
                    sound = {
                    name = L["Sound"],
                    desc = L["Must be a path to an in-game sound or in the Interface directory."],
                    type = "input",
                    get = function(info) return Medley.db.profile.WhisperNotifySound end,
                    set = function(info,val) Medley.db.profile.WhisperNotifySound = val end
                    },
                }
            },
            follow = {
                type = "group",
                order = 8,
                name = L["Auto Follow"],
                desc = L["Plays when you auto-follow someone."],
                args = {
                    enabled = {
                    name = L["Enabled"],
                    desc = L["Enables or disables this sound."],
                    type = "toggle",
                    get = function(info) return Medley.db.profile.FollowEnabled end,
                    set = function(info,val) Medley.db.profile.FollowEnabled = val end
                    },
                    notice = {
                    type = "description",
                    name = L["NOTE: This event only triggers the train (choo choo!) emote at this time. In a later release I will modify it to either be the emote or a custom sound. This is the only part of the mod that other players can 'hear', since it actually makes your character do the train! ;)"],
                    },
                }
            },
            
        }
        },
        help = {
        type = "group",
        order = 3,
        name = L["Help"],
        desc = L["Some help & tips."],
        args = {
            about = {
            type = "description",
            order = 1,
            name = L["This is my first attempt at writing a mod and it's been fun so far! I appreciate everyone who helps me test it until it's officially ready. I created it because I wanted to make it easier to add my own sounds for certain events. Hope you enjoy it!"],
            },
            header1 = {
            type = "header",
            order = 2,
            name = L["In-Game Sounds"],
            },
            ingamesounds = {
            type = "description",
            order = 3,
            name = L["To use a sound file that is built-in to the game, browse the lists located on this URL: http://www.wowwiki.com/API_PlaySoundFile and paste the path into the corresponding box for the event you want to customize. The sound path must follow this format example: Path\\To\\Sound\\File.wav, but it does not have to be a wav file."],
            },
            header2 = {
            type = "header",
            order = 4,
            name = L["Custom Sounds"],
            },
            customsounds = {
            type = "description",
            order = 5,
            name = L["To use a custom sound file that is not in the game, move the file you want into the 'Sounds' folder in the Medley folder. Then type this path into the box: Interface\\AddOns\\Medley\\sounds\\SOUNDNAME.wav ... change 'SOUNDNAME' to the exact file name of the sound and make sure to use the correct extension (.wav, .mp3, whatever the file is) or it will not work."],
        },
            header3 = {
            type = "header",
            order = 6,
            name = L["More Ideas?"],
            },
            moreideas = {
            type = "description",
            order = 7,
            name = L["Do you have an idea for a sound event? Please leave me a comment on Medley's download page, my portal, or email me and I will see if it can be done!"],
            },
        }
       }
   }
}

Medley.defaults = {
    profile = {
        QuestObjectivesEnabled = true,
        QuestObjectivesSound = "Sound\\Creature\\Peon\\PeonReady1.wav",
        QuestCompleteEnabled = true,
        QuestCompleteSound = "Sound\\Creature\\Peon\\PeonBuildingComplete1.wav",
        QuestFailedEnabled = false,
        QuestFailedSound = "Sound\\Character\\PlayerExertions\\OrcMale\\OrcMaleMainDeathA.wav",
        LevelUpEnabled = true,
        LevelUpSound = "Sound\\Event Sounds\\Event_wardrum_ogre.wav",
        DuelFinishedEnabled = false,
        DuelFinishedSound = "Sound\\Events\\GuldanCheers.wav",
        MailNotifyEnabled = true,
        MailNotifySound = "Sound\\Spells\\KillCommand.wav",
        WhisperNotifyEnabled = true,
        WhisperNotifySound = "Sound\\Event Sounds\\Wisp\\WispReady1.wav",
        FollowEnabled = true,
   }
}

function Medley:Objective_Update(event, title, uid, objective, had, got, need, t)
    if Medley.db.profile.QuestObjectivesEnabled then
		if got == need then
			local _,_,_,_,_,objectives,complete,_,_,_ = quixote:GetQuestByUid(uid)
			if not complete and objectives > 1 then
				PlaySoundFile(Medley.db.profile.QuestObjectivesSound)
			end
		end
	end
end

function Medley:Quest_Complete()
    if Medley.db.profile.QuestCompleteEnabled then
        PlaySoundFile(Medley.db.profile.QuestCompleteSound)
    end
end

function Medley:Quest_Failed()
    if Medley.db.profile.QuestFailedEnabled then
        PlaySoundFile(Medley.db.profile.QuestFailedSound)
    end
end

function Medley:PLAYER_LEVEL_UP()
    if Medley.db.profile.LevelUpEnabled then
        PlaySoundFile(Medley.db.profile.LevelUpSound)
    end
end

function Medley:DUEL_FINISHED()
    if Medley.db.profile.DuelFinishedEnabled then
        PlaySoundFile(Medley.db.profile.DuelFinishedSound)
    end
end

function Medley:AUTOFOLLOW_BEGIN()
    if Medley.db.profile.FollowEnabled then
        DoEmote("TRAIN")
    end
end

function Medley:MAIL_INBOX_UPDATE() arg = 0 end
function Medley:MAIL_CLOSED() arg = 1 end
function Medley:UPDATE_PENDING_MAIL()
    if Medley.db.profile.MailNotifyEnabled then
        if HasNewMail() and arg == 1 then
            PlaySoundFile(Medley.db.profile.MailNotifySound)
        end
    end
end

function Medley:CHAT_MSG_WHISPER()
    if Medley.db.profile.WhisperNotifyEnabled then
        PlaySoundFile(Medley.db.profile.WhisperNotifySound)
    end
end